pub struct SecurityError(pub &'static str);Expand description
A refused security configuration, credential file, TLS material or key set.
The message is a static description of which check failed. It never contains credential, key or token material, so it is safe to log.
Tuple Fields
0: &'static strTrait Implementations
Sourceimpl Clone for SecurityError
impl Clone for SecurityError
impl Copy for SecurityError
Sourceimpl Debug for SecurityError
impl Debug for SecurityError
Sourceimpl Display for SecurityError
impl Display for SecurityError
impl Eq for SecurityError
Sourceimpl Error for SecurityError
impl Error for SecurityError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for SecurityError
impl PartialEq for SecurityError
impl StructuralPartialEq for SecurityError