pub struct ApiError {
pub status: StatusCode,
pub code: &'static str,
pub title: String,
pub generation: Option<Generation>,
pub balance_exhaustion: Option<BalanceExhaustion>,
pub balance_shortfall: Option<BalanceShortfall>,
}Fields
status: StatusCodecode: &'static strtitle: Stringgeneration: Option<Generation>balance_exhaustion: Option<BalanceExhaustion>balance_shortfall: Option<BalanceShortfall>Implementations
Sourceimpl ApiError
impl ApiError
pub fn forbidden() -> Self
pub fn not_found(code: &'static str, title: impl Into<String>) -> Self
pub fn revoked(generation: Generation) -> Self
pub fn bad_request(code: &'static str, title: impl Into<String>) -> Self
Sourcepub fn not_implemented(code: &'static str, title: impl Into<String>) -> Self
pub fn not_implemented(code: &'static str, title: impl Into<String>) -> Self
The backend cannot answer this at all, as opposed to answering “nothing” — a distinction a caller must be able to act on differently (GL-48).